Skip to contents

Fits prediction model for all features and selected features.

Usage

ULTRA(data, namebin)

Arguments

data

dataframe containing z-scaled continuous features and single binary outcome

namebin

name of the binary outcome variable

Value

Displays a combined cowplot. Note the individual plots can be accessed from the object returned by the ULTRA function.