Skip to contents

Plots the AUC from the prediction model for all features and selected features.

Usage

ULTRAplot(results)

Arguments

results

The object returned by the ULTRA function.

Value

Visual output displaying a combined cowplot. Note the individual plots can be accessed from the object returned by the ULTRA function.