ULTRAplot.Rd
Plots the AUC from the prediction model for all features and selected features.
ULTRAplot(results)
The object returned by the ULTRA function.
Visual output displaying a combined cowplot. Note the individual plots can be accessed from the object returned by the ULTRA function.